==> eventdataR_0.1.0.tar.gz: eventdataR/R/datasets_documentation.R <==

#' @name BPIC14_incident_case_attributes
#' @title BPI Challenge 2014 Incidents
#' @description Dataset originating of the BPI Challenge 2014, organized by the BPI Workshop
#' @docType data
#' @format tbl_df containing 4000 observations with 28 variables
#' @keywords datasets
"BPIC14_incident_case_attributes"

#' @name BPIC14_incident_log
#' @title BPI Challenge 2014 Incident Activities
#' @description Dataset originating of the BPI Challenge 2014, organized by the BPI Workshop
#' @docType data
#' @format eventlog containing 39911 events
#' @keywords datasets
"BPIC14_incident_log"

#' @name BPIC15_1
#' @title BPI Challenge 2015 Log Municipality 1
#' @description Dataset originating of the BPI Challenge 2014, organized by the BPI Workshop
#' @docType data
#' @format eventlog containing 52217 events
#' @keywords datasets
"BPIC15_1"

#' @name BPIC15_1_imported
#' @title BPI Challenge 2015 Log Municipality 1
#' @description Dataset originating of the BPI Challenge 2014, organized by the BPI Workshop
#' @docType data
#' @format eventlog containing 52217 events, as imported from xes
#' @keywords datasets
"BPIC15_1_imported"

#' @name csv_example
#' @title Example eventlog in data.frame format
#' @description Artifical eventlog
#' @docType data
#' @format data.frame containing 12766 observations with 5 variables, containg event data
#' @keywords datasets
"csv_example"

#' @name example_log
#' @title Example eventlog
#' @description Artifical eventlog
#' @docType data
#' @format Eventlog containing 12766 events
#' @keywords datasets
"example_log"


#' @name example_log
#' @title Patients eventlog
#' @description Artifical eventlog about patients
#' @docType data
#' @format Eventlog containing 500 patient cases
#' @keywords datasets
"patients"

==> eventdataR_0.1.1.tar.gz: eventdataR/R/datasets_documentation.R <==

#' @name BPIC14_incident_case_attributes
#' @title BPI Challenge 2014 Incidents
#' @description Dataset originating of the BPI Challenge 2014, organized by the BPI Workshop
#' @docType data
#' @format tbl_df containing 4000 observations with 28 variables
#' @keywords datasets
"BPIC14_incident_case_attributes"

#' @name BPIC14_incident_log
#' @title BPI Challenge 2014 Incident Activities
#' @description Dataset originating of the BPI Challenge 2014, organized by the BPI Workshop
#' @docType data
#' @format eventlog containing 39911 events
#' @keywords datasets
"BPIC14_incident_log"

#' @name BPIC15_1
#' @title BPI Challenge 2015 Log Municipality 1
#' @description Dataset originating of the BPI Challenge 2014, organized by the BPI Workshop
#' @docType data
#' @format eventlog containing 52217 events
#' @keywords datasets
"BPIC15_1"

#' @name BPIC15_1_imported
#' @title BPI Challenge 2015 Log Municipality 1
#' @description Dataset originating of the BPI Challenge 2014, organized by the BPI Workshop
#' @docType data
#' @format eventlog containing 52217 events, as imported from xes
#' @keywords datasets
"BPIC15_1_imported"

#' @name csv_example
#' @title Example eventlog in data.frame format
#' @description Artifical eventlog
#' @docType data
#' @format data.frame containing 12766 observations with 5 variables, containg event data
#' @keywords datasets
"csv_example"

#' @name example_log
#' @title Example eventlog
#' @description Artifical eventlog
#' @docType data
#' @format Eventlog containing 12766 events
#' @keywords datasets
"example_log"


#' @name example_log
#' @title Patients eventlog
#' @description Artifical eventlog about patients
#' @docType data
#' @format Eventlog containing 500 patient cases
#' @keywords datasets
"patients"

#' @name sepsis
#' @title Sepsis Cases - Event Log
#' @description This real-life event log contains events of sepsis cases from a hospital. Sepsis is a life threatening condition typically caused by an infection. One case represents the pathway through the hospital. The events were recorded by the ERP (Enterprise Resource Planning) system of the hospital. There are about 1000 cases with in total 15,000 events that were recorded for 16 different activities. Moreover, 39 data attributes are recorded, e.g., the group responsible for the activity, the results of tests and information from checklists. Events and attribute values have been anonymized. The time stamps of events have been randomized, but the time between events within a trace has not been altered.
#'#' @docType data
#' @formate Eventlog containing 1050 cases
#' @keywords datasets
#' @references Analyzing the Trajectories of Patients with Sepsis using Process Mining (Felix Mannhardt and Daan Blinde, CEUR Workshop Proceedings Vol-1859 RADAR+EMISA 2017)
#' @source <http://data.4tu.nl/repository/uuid:915d2bfb-7e84-49ad-a286-dc35f063a460>
"sepsis"
